




from .tools import TYPE_NULL, TYPE_BOOL, TYPE_INT, TYPE_FLOAT, TYPE_STR, TYPE_ARRAY, TYPE_OBJECT, \
	ALL_TYPES_LIST, ALL_TYPES_NAME_LIST, ALL_TYPES_SET, \
	getTypeID, getTypeIDs, getTypeIDOfValue, getTypeIDOfValueNonInt, getTypeIDOfType, getTypeIDOfTypeNonInt, jsonIsEqual







__version__ = "0.2022.3.2"